import axios from '@/api/axios.ts'
import { BasePaginationData, BaseRespData } from '@/types/api'
export interface factoryWarehouseInfo{
  pageSize:number
  currentPage:number
  total?:number
}
export interface UpdateDefaulted{
  id?: number;
  defaulted: number;
}
export interface warehouseInfo{
  id?: number;
  name: string;
  code: string;
  sort: string;
  defaulted: number;
  factoryId?: number;
  factoryCode?: string;
  remarks: string
}
interface WarehouseWarningData {
  id: number;
  factoryId: number;
  warehouseId: number;
  warehouseName: string;
  warehouseLocationId: number;
  locationName: string;
  warehouseSku: string;
  skuName: string;
  unit: string;
  occupyInventory: number;
  freezeInventory: number;
  inventory: number;
  upperLimit: number;
  floorLimit: number;
  productNumber: string;
  itemSort: number;
  dataVersion: number;
  status: number;
  createTime: string;
  updateTime: string;
}
export function getFactoryWarehouseInfo(data: factoryWarehouseInfo) {
  return axios.post<never, BasePaginationData<warehouseInfo>>(
    'factoryWarehouseInfo/list_page',
    data,
  )
}
export function createWarehouseApi(data:warehouseInfo) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/add',
    data
  )
}

export function createWarehouseInventoryApi(data:WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/add',
    data
  )
}
export function updateWarehouseApi(data:warehouseInfo | UpdateDefaulted) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/update',
    data
  )
}
export function updateWarehouseInventoryApi(data:WarehouseWarningData) {
  return axios.post<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/update',
    data
  )
}
export function deleteWarehouseApi(ids:string) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseInfo/delete',
    {
      params:{ids}
    },
  )
}
export function deleteWarehouseInventory(ids:string) {
  return axios.get<never, BaseRespData<never>>(
    '/factoryWarehouseInventory/delete',
    {
      params:{ids}
    },
  )
}
